@@ -27,7 +27,7 @@ import urllib
 from dataclasses import dataclass
 from functools import partial
 from typing import Dict, Mapping, Optional, Tuple, Union
-import tqdm
+from time import time
 from datalabs.features import Features
 from datalabs.utils.mock_download_manager import MockDownloadManager
 
@@ -55,6 +55,11 @@ from .utils.filelock import FileLock
 from .utils.info_utils import get_size_checksum_dict, verify_checksums, verify_splits
 from .utils.streaming_download_manager import StreamingDownloadManager
 from multiprocess import Pool
+from p_tqdm import p_map
+from .operations.featurize.text_matching import (
+    get_features_sample_level,
+    get_schema_of_sample_level_features,
+    )
 
 import sys
 
@@ -1101,25 +1106,15 @@ class GeneratorBasedBuilder(DatasetBuilder):
             check_duplicates=True,
         ) as writer:
             try:
-                if self.feature_expanding:
-                    if self.num_proc == 1:
-                        generator = map(lambda i: i[1], generator)
-                    else:
-                        with Pool(processes=self.num_proc) as pool:
-                            generator = pool.map(lambda i: i[1], generator)
-                    generator = enumerate(generator)
-
-                iter = utils.tqdm(
+                for key, record in utils.tqdm(
                     generator,
                     unit=" examples",
                     total=split_info.num_examples,
                     leave=False,
                     disable=bool(logging.get_verbosity() == logging.NOTSET),
-                )
-                for key, record in iter:
+                ):
                     example = self.info.features.encode_example(record)
                     writer.write(example, key)
-
             finally:
                 num_examples, num_bytes = writer.finalize()
 
